#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

#GLOBALS:
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/upgrade_utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/argocd_utils.sh"


function disable_argocd_self_heal() {
  local argoApp="$1"
  local app

  info "disable argo application ${argoApp} selfHeal"
  app=$(kubectl get application "${argoApp}" -n argocd --ignore-not-found)
  if [[ -n "${app}" ]]; then
    kubectl patch application "${argoApp}" -n argocd --type=merge -p '{"spec" : {"syncPolicy" : {"automated" : {"selfHeal": false }}}}'
  fi
  info "argo application ${argoApp} selfHeal disabled"
}


function main() {

disable_argocd_self_heal "fabric-installer"
disable_argocd_self_heal "fabric-configure"
disable_argocd_self_heal "uipath-gatekeeper"

  kubectl delete ConstraintTemplate k8spspprivilegedcontainer k8sallowedrepos \
                          k8sblockhostnetwork k8sblocksecretenvvariable k8spspallowedusers \
                          k8spspallowprivilegeescalationcontainer k8spspcapabilities \
                          k8sblocksvcexternalips k8spspvolumetypes k8srequiredlabels k8spspreadonlyrootfilesystem || true
  kubectl delete K8sPSPPrivilegedContainer psp-privileged-container || true
  kubectl delete K8sPSPAllowedUsers psp-pods-allowed-user-ranges || true
  kubectl delete K8sPSPAllowPrivilegeEscalationContainer psp-allow-privilege-escalation-container || true
  kubectl delete K8sPSPVolumeTypes psp-volume-types || true
  kubectl delete K8sPSPReadOnlyRootFilesystem psp-readonlyrootfilesystem || true
  kubectl delete K8sPSPCapabilities psp-capabilities || true
  kubectl delete K8sBlockSvcExternalIps k8sblocksvcexternalips || true
  kubectl delete K8sBlockHostNetwork block-host-network || true
  kubectl delete K8sBlockSecretEnvVariable block-secret-cm-env || true
}

info "Deleting gatekeeper constraints"
main &> ./constraints-deletion.logs