#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

#GLOBALS:
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/upgrade_utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/argocd_utils.sh"

function disable_argocd_self_heal() {
  local argoApp="$1"
  local app

  info "disable argo application ${argoApp} selfHeal"
  app=$(kubectl get application "${argoApp}" -n argocd --ignore-not-found)
  if [[ -n "${app}" ]]; then
    kubectl patch application "${argoApp}" -n argocd --type=merge -p '{"spec" : {"syncPolicy" : {"automated" : {"selfHeal": false }}}}'
  fi
  info "argo application ${argoApp} selfHeal disabled"
}

function main() {
 if [[ "${NODE_ROLE}" != "none" ]]; then
    info "Skipping deleting psp, as this is not the first node"
    return
fi

  info "Disabling the Argocd app for deleting the deprecated APIs"
  disable_argocd_self_heal "uipath"
  disable_argocd_self_heal "aicenter"
  disable_argocd_self_heal "fabric-installer"
  disable_argocd_self_heal "fabric-configure"
  disable_argocd_self_heal "gatekeeper"
  disable_argocd_self_heal "gatekeeper-crd"
  disable_argocd_self_heal "rancher-logging"
  disable_argocd_self_heal "rancher-monitoring"
  disable_argocd_self_heal "rancher-monitoring-crd"
  disable_argocd_self_heal "rook-ceph-operator"
  disable_argocd_self_heal "platform"
  disable_argocd_self_heal "orchestrator"
  disable_argocd_self_heal "webhook"
  disable_argocd_self_heal "rabbitmq-cluster"

  info "Deleting the PSPs for the Upgrade"
  for i in $(kubectl get psp -o name | grep -v -e longhorn-psp -e global-restricted-psp -e system-unrestricted-psp -e global-unrestricted-psp); do
    kubectl delete --ignore-not-found "$i"
  done

  info "Deleting the PDBs for the Upgrade"
  kubectl delete --all pdb -n uipath --ignore-not-found
  kubectl delete --all pdb -n rabbitmq --ignore-not-found

  info "Deleting the HPA for the Upgrade"
  kubectl delete --all hpa -n uipath --ignore-not-found
  kubectl delete hpa istiod -n istio-system --ignore-not-found

}

info "Deleting Deprecated resource"
main