#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.
#GLOBALS:
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/utils.sh"

# The upgrade version should be higher than all the patched service versions
function is_patched_component_version_compatible() {
  declare -A products_map
  local helmchart_file="$1"
  local uipath_application
  local incoming_version
  local app_name="uipath"

  # Get already patched components and create map of them (key=component, value=version)
  uipath_application=$(kubectl -n argocd get application "${app_name}" -ojson --ignore-not-found -o=template='{{.spec.source.helm.values}}')
  if [[ -z "${uipath_application}" ]]; then
    error "Application ${app_name} not found"
  fi

  while IFS= read -r line; do
      key=$(echo "$line" | awk '{print $1}')
      value=$(echo "$line" | awk '{print $2}')
      products_map["$key"]="$value"
  done < <(echo "${uipath_application}" | \
  yq -o=json 'select(.applications.products != null)' | \
  jq -r '.applications.products | to_entries[] | "\(.key) \(.value.source.version)"')

  # Check if the patch version is less than the version in the helm chart file
  for key in "${!products_map[@]}"; do
    incoming_version=$(jq -r --arg name "${key}" '.uipath_charts[] | select(.name == $name) | .version' "${helmchart_file}")
    if [ -z "$incoming_version" ]; then
      error "Component ${key} is not found in the helm chart file"
    fi

    if [[ $(bash "${MODULES_DIR}/semver-custom.sh" "${products_map[$key]}" "${incoming_version}" ) == "1" ]]; then
      error "Unsupported upgrade: current component ${key} version ${products_map[$key]} is higher than the new version ${incoming_version}"
    fi
  done
}

info "Checking if the patched component version is compatible with the upgrade version"
if [[ $NODE_ROLE == "none" || $NODE_ROLE == "server" ]]; then
  is_patched_component_version_compatible "${MODULES_DIR}/../versions/helm-charts.json"
fi