#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

#GLOBALS:
SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/utils.sh"

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/k8sutils.sh"

#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/upgrade_utils.sh"

function main() {
  # Scale-up workload which were scaled down in infra and required in fabric

  info "Scaling up rook-ceph mon"
  scale_up_ceph_mon
  rabbitmq_operator=$(kubectl get application -n argocd rabbitmq-operator --ignore-not-found)
  if [[ -n "${rabbitmq_operator}" ]]; then
    scale_up_deployment "rabbitmq-cluster-operator" "rabbitmq-system" 1
  fi

  insight=$(kubectl get application -n argocd insights --ignore-not-found)
  if [[ -n "${insight}" ]]; then
    scale_up_deployment "insights-insightslooker" "uipath" 1
  fi

  # disable mongodb self-heal and scale down
  mongodb=$(kubectl get application -n argocd mongodb --ignore-not-found)
  if [[ -n "${mongodb}" ]]; then
    scale_up_deployment "mongodb-kubernetes-operator" "mongodb" 1
  fi

  pushgateway=$(kubectl get application -n argocd pushgateway --ignore-not-found)
  if [[ -n "${pushgateway}" ]]; then
    uipath_pg=$(kubectl get deploy -n uipath pushgateway-prometheus-pushgateway --ignore-not-found)
    if [[ -n "${uipath_pg}" ]]; then
      scale_up_deployment "pushgateway-prometheus-pushgateway" "uipath" 1
    else
      # In older release, scale-up from namespace cattle-monitoring-system
      scale_up_deployment "pushgateway-prometheus-pushgateway" "cattle-monitoring-system" 1
    fi
  fi

  scale_up_deployment "rancher-monitoring-operator" "cattle-monitoring-system" 1
}

main