#!/bin/bash

# Copyright UiPath 2021
#
# =================
# LICENSE AGREEMENT
# -----------------
#   Use of paid UiPath products and services is subject to the licensing agreement
#   executed between you and UiPath. Unless otherwise indicated by UiPath, use of free
#   UiPath products is subject to the associated licensing agreement available here:
#   https://www.uipath.com/legal/trust-and-security/legal-terms (or successor website).
#   You must not use this file separately from the product it is a part of or is associated with.

SCRIPT_DIR=$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)
if [[ -z "${SCRIPT_DIR}" ]]; then
  error "Could not determine script path"
fi
MODULES_DIR=$(cd "${SCRIPT_DIR}/../../Modules" && pwd)
if [[ -z "${MODULES_DIR}" ]]; then
  error "Could not determine modules path"
fi
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}/utils.sh"
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/install-longhorn.sh
#shellcheck disable=SC1090,SC1091
source "${MODULES_DIR}"/longhornutils.sh

function main() {
  if [[ "${NODE_ROLE}" != "none" ]]; then
    info "Skipping longhorn upgrade, as this is not the first node"
    return
  fi
# Scaling down rancher-webhook for offline as they have dependency on docker registry and scaling them up in fabric
  registry=$(kubectl get deploy -n docker-registry docker-registry --no-headers --ignore-not-found | wc -l)
  if [[ "${registry}" -eq 1 ]]; then
    scale_down_rancher_webhook
  fi
  
  export_helm_registry_info
  load_lh_variables
  longhorn_prereq
  if [[ ${INSTALL_TYPE} == "offline" && ${DO_UPGRADE} == "1" ]]; then
      push_longhorn_images_to_docker_registry
      run_longhorn_image_copier
  fi
  install_longhorn
  test_longhorn

  # We are scaling down workloads to mitigate multi-attach issue ref: https://github.com/longhorn/longhorn/issues/6804
  scale_down_lh_consumer
  
}

# This script suppose to be at pre fabric however the argocd installation and
# argo app sync happens before the pre hook, so this is called at post fabric upgrade
info "Upgrading longhorn at upgrade hooks"
main